<?php

/**
 * @file
 * Services API resources callbacks.
 */

/**
 * Access callback for 'path' services resource.
 *
 * @param string $op
 *   the operation ('view')
 *
 * @param array $args
 *   the service callback arguments
 *
 * @return bool
 *   TRUE if access is granted, FALSE otherwise
 */
function _services_path_resource_access($op, $args) {
  if ($op == 'view') {
    $path = reset($args);
    $path = _services_path_normalize($path);
    $item = menu_get_item($path);
    if(empty($item)){
      services_error('Resource not found', 404);
      return FALSE;
    }
    return $item['access'];
  }
  return TRUE;
}

/**
 * Retrieve operation callback for 'path' resource.
 *
 * @param string $path
 *   the path argument, with '/' characters replaced with '|'.
 *
 * @return array
 *   information about the given path
 */
function _services_path_resource_retrieve($path = NULL) {
  global $language;
  $path   = _services_path_normalize($path);
  $item   = menu_get_item($path);
  $is_front = $path === variable_get('site_frontpage', 'node');
  $result = array(
    'canonical' => $is_front ? '' : drupal_get_path_alias($path, $language->language),
    'is_front' => $is_front,
  );
  $result += module_invoke_all('services_path_handle', $item, $path);
  return $result;
}

function _services_path_normalize($path_arg){

  $cache = &drupal_static(__FUNCTION__, array());

  if(!empty($cache[$path_arg])){
    return $cache[$path_arg];
  }

  if (empty($path_arg)) {
    $path = variable_get('site_frontpage', 'node');
  }else {
    $path = $path_arg;
  }
  $redirect =_services_path_resource_redirect($path);
  if(!empty($redirect)){
    $path = $redirect->redirect;
  }
  $cache[$path_arg] = drupal_get_normal_path($path);
  return $cache[$path_arg];

}

function _services_path_resource_redirect($path){

  if(module_exists('redirect')){
    $redirect = redirect_load_by_source($path, $GLOBALS['language']->language);
    if(!empty($redirect)){
      return $redirect;
    }
  }

  return FALSE;

}
